package com.hz.pm.api.common.statemachine.event;

import com.hz.pm.api.projectlib.model.enumeration.status.ProjectStatus;
import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * <p>
 * 项目状态变更事件
 * </p>
 *
 * @author WendyYang
 * @since 20:20 2024/4/2
 */
@Getter
@AllArgsConstructor
public enum ProjectStateChangeEvent implements AbstractStateChangeEvent {

    /**
     * 项目申报提交(项目状态进入：单位内部审核中)
     */
    PROJECT_APPLICATION_SUBMIT(ProjectStatus.TO_BE_DECLARED.getCode(), null, null),

    COMPLIANCE_REVIEW_FAILED(null, ProjectStatus.ON_COMPLIANCE_REVIEW.getCode(), null),

    COMPLIANCE_REVIEW_RESUBMIT(ProjectStatus.COMPLIANCE_REVIEW_FAILED.getCode(), null, null),

    COMPLIANCE_REVIEW_PASS(ProjectStatus.ON_COMPLIANCE_REVIEW.getCode(), null, null),

    PROJECT_REVIEW_FAILED(null, ProjectStatus.ON_PROJECT_REVIEW.getCode(), null),

    PROJECT_REVIEW_PASS(ProjectStatus.ON_PROJECT_REVIEW.getCode(), null, null),

    ANNUAL_PLAN_PASS(ProjectStatus.ON_ANNUAL_PLAN.getCode(), null, null),

    /**
     * 年度计划项目开启方案申报(项目状态变为：方案待申报)
     */
    ANNUAL_PLAN_PROJECT_OPEN_PLAN_DECLARE(ProjectStatus.ON_ANNUAL_PLAN.getCode(), null, null),

    /**
     * 立项备案提交
     */
    DECLARED_RECORD_SUBMIT(ProjectStatus.DECLARED_APPROVED_TO_BE_RECORD.getCode(), null, null),

    /**
     * 立项备案重新提交
     */
    DECLARED_RECORD_RESUBMIT(ProjectStatus.DECLARED_APPROVED_RECORD_FAILED.getCode(), null, null),

    /**
     * 立项备案通过
     */
    DECLARED_RECORD_PASS(ProjectStatus.DECLARED_APPROVED_RECORD_AUDITING.getCode(), null, null),

    /**
     * 立项备案不通过
     */
    DECLARED_RECORD_FAILED(null, ProjectStatus.DECLARED_APPROVED_RECORD_AUDITING.getCode(), null),

    //==================================================================================================================

    /**
     * 发布采购公告
     */
    SUBMIT_PURCHASE_NOTICE(ProjectStatus.TO_BE_PURCHASED.getCode(), null, null),

    /**
     * 填写实施计划
     */
    SUBMIT_OPERATION_PLAN(ProjectStatus.ON_PURCHASING.getCode(), null, null),

    /**
     * 上传初验材料
     */
    SUBMIT_FIRST_INSPECTED_FILES(ProjectStatus.TO_BE_FIRST_INSPECTED.getCode(), null, null),
    /**
     * 终验申请(项目状态变为：终验审核中)
     */
    FINAL_ACCEPTANCE_APPLICATION(ProjectStatus.ON_PILOT_RUNNING.getCode(), null, null),
    /**
     * 终验审核不通过(项目状态变为：终验审核不通过)
     */
    FINAL_ACCEPTANCE_REJECT(null, ProjectStatus.ON_FINALLY_INSPECTED.getCode(), null),
    /**
     * 终验审核通过(项目状态变为：已归档)
     */
    FINAL_ACCEPTANCE_PASS(ProjectStatus.ON_FINALLY_INSPECTED.getCode(), null, null),

    /**
     * 终验审核中时被撤回(项目状态进入：待终验)
     */
    FINAL_ACCEPTANCE_IS_UNDER_REVIEW_WITHDRAW(null, null, ProjectStatus.ON_FINALLY_INSPECTED.getCode()),

    /**
     * 重新提交 终验
     */
    FINAL_RE_ACCEPTANCE_APPLICATION(ProjectStatus.FINALLY_INSPECTED_FAILED.getCode(), null, null);


    private final Integer passStatusCode;
    private final Integer rejectStatusCode;
    private final Integer withdrawStatusCode;

}
